@@ -3,9 +3,11 @@ Main interface for codedeploy service type definitions.
 
 Usage::
 
-    from mypy_boto3.codedeploy.type_defs import AlarmConfigurationTypeDef
+    ```python
+    from mypy_boto3_codedeploy.type_defs import AlarmConfigurationTypeDef
 
     data: AlarmConfigurationTypeDef = {...}
+    ```
 """
 from datetime import datetime
 import sys
